@@ -76,15 +76,17 @@ USAChoropleth = R6Class("USAChoropleth",
       if (is.numeric(choropleth.df$value))
       {
         ggplot(choropleth.df, aes(long, lat, group = group)) +
-          geom_polygon(aes(fill = value), color = "dark grey", size = 0.2) + 
+          self$ggplot_polygon  + 
           self$get_scale() + 
+          self$projection + 
           theme;
       } else { # assume character or factor
         stopifnot(length(unique(na.omit(choropleth.df$value))) <= 9) # brewer scale only goes up to 9
         
         ggplot(choropleth.df, aes(long, lat, group = group)) +
-          geom_polygon(aes(fill = value), color = "dark grey", size = 0.2) + 
+          self$ggplot_polygon  + 
           self$get_scale() + 
+          self$projection +
           theme;
       }
     },
